import cx from 'classnames'
import React from 'react'
import autoBind from 'react-autobind'
import ReactTimeout from 'react-timeout'

// Components
import Item from './components/Item'
import Main from './components/Main'

// Styles
import './styles'

class Actions extends React.Component {
	constructor(props) {
		super()
		autoBind(this)

		this.state = {
			timeout: null,
			hide: true
		}

        if (props.open === null) {
            if (props.on === 'click') {
                this.onEvent = {
                    onClick: this.handleClick
                }
            } else if(props.on === 'hover') {
                this.onEvent = {
                    onMouseEnter: this.handleUnHide,
                    onMouseLeave: this.handleHide
                }
            }
        } else {
            this.onEvent = {}
        }
    }

	handleUnHide() {
        this.props.clearTimeout(this.state.timeout)
        this.setState({
            timeout: null,
            hide: false
        })
	}

	handleHide() {
		this.setState({
			timeout: this.props.setTimeout(() => {
				this.setState({ hide: true })
			}, 300)
		})
	}

    handleClick() {
        if (this.state.hide) this.handleUnHide()
        else this.handleHide()
    }

    componentWillReceiveProps(nextProps) {
        if (nextProps.open !== null) {
            if (nextProps.open === true) this.handleUnHide()
            else this.handleHide()
        }
    }

	render() {
        const Component = this.props.as

		return (
			<Component
			{ ...this.onEvent }
			className={ cx('et-module-actions', this.props.className, {
				'et-left': this.props.left,
        'et-top': this.props.top,
        'et-hide': this.state.hide,
        'et-click': this.props.on === 'click' || this.props.open !== null,
        'et-hiding': this.state.timeout !== null
			})}>{ this.props.children }</Component>
		)
	}
}

Actions.Item = Item
Actions.Main = Main
Actions.defaultProps = {
    open: null,
    left: false,
    top: false,
    on: 'hover',
    as: 'div'
}

export default ReactTimeout(Actions)
