import cx from 'classnames'
import React from 'react'
import IsoScroll from 'iso-scroll'

import {
    Segment,
    Card,
    Label,
    Icon,
    //Button,
    Header
} from 'semantic-ui-react'

import './styles'

const Cards = ({ count, cards, title, icon, children, empty, showMore, onShowMore }) => (
    <Segment className='et-module-cards'>
        <Label attached='top'>
            { icon && <Icon name={ icon } className='et-icon' /> }
            { title }
            <a onClick={ onShowMore } className='et-show-more'>
                Show { showMore ? 'Less' : 'More' }
            </a>
            { count && <Label color='red' floating circular>{ count }</Label> }
        </Label>
        <IsoScroll>
        {
            React.Children.count(children) ? (
                <div className='et-container'>
                    <Card.Group
                    className={ cx('et-group', { 'et-full': showMore }) }
                    itemsPerRow={ cards }
                    stackable
                    doubling>{ children }</Card.Group>
                </div>
            ) : (
                <Header textAlign='center' size='large'>{ empty }</Header>
            )
        }
        </IsoScroll>
    </Segment>
)

/**
 * SIDE SCROLLING
 * -----------------------------------------------------
    <div className='et-container'>
        <div className='et-nav-left'>
            <Button circular icon>
                <Icon name='angle left' size='large'/>
            </Button>
        </div>
        <Card.Group
        className='et-group'
        itemsPerRow={ cards }
        stackable>{ children }</Card.Group>
        <div className='et-nav-right'>
            <Button circular icon>
                <Icon name='angle right' size='large' />
            </Button>
        </div>
    </div>
 * -----------------------------------------------------
 */

Cards.Card = Card
Cards.defaultProps = {
    count: false,
    showMore: false,
    cards: 4,
    empty: 'No Items'
}

export default Cards
