import React from 'react'
import cx from 'classnames'
import $ from 'jquery'

import '../scripts/transition'
import '../scripts/dropdown'

class Dropdown extends React.Component {
  constructor(props) {
      super(props)

      this.dropdown = React.createRef()
  }

  componentDidMount() {
    const on = {}

    if (this.props.onChange !== null) {
      on.onChange = this.props.onChange
    }
    if (this.props.onAdd !== null) {
      on.onAdd = this.props.onAdd
    }
    if (this.props.onRemove !== null) {
      on.onRemove = this.props.onRemove
    }
    if (this.props.onLabelCreate !== null) {
      on.onLabelCreate = this.props.onLabelCreate
    }
    if (this.props.onLabelRemove !== null) {
      on.onLabelRemove = this.props.onLabelRemove
    }
    if (this.props.onLabelSelect !== null) {
      on.onLabelSelect = this.props.onLabelSelect
    }
    if (this.props.onNoResults !== null) {
      on.onNoResults = this.props.onNoResults
    }
    if (this.props.onShow !== null) {
      on.onShow = this.props.onShow
    }
    if (this.props.onHide !== null) {
      on.onHide = this.props.onHide
    }

    $(this.dropdown.current).dropdown({
      on: this.props.on,
      ignoreCase: this.props.ignoreCase,
      allowReselection: this.props.allowReselection,
      allowAdditions: this.props.allowAdditions,
      hideAdditions: this.props.hideAdditions,
      action: this.props.action,
      minCharacters: this.props.minCharacters,
      match: this.props.match,
      selectOnKeydown: this.props.selectOnKeydown,
      forceSelection: this.props.forceSelection,
      allowCategorySelection: this.props.allowCategorySelection,
      placeholder: this.props.placeholder,
      direction: this.props.direction,
      keepOnScreen: this.props.keepOnScreen,
      fullTextSearch: this.props.fullTextSearch,
      preserveHTML: this.props.preserveHTML,
      sortSelect: this.props.sortSelect,
      showOnFocus: this.props.showOnFocus,
      allowTab: this.props.allowTab,
      duration: this.props.duration,
      ...on
    })
  }

  render() {
    const {
      children,
      name,
      className,
      icon,
      text,
      type
    } = this.props

    return (
      <div className={ cx("ui dropdown", className, type) } ref={ this.dropdown }>
        <input type="hidden" name={ name } />
        <i className={ cx('icon', icon) }></i>
        <div className="default text">{ text }</div>
        <div className="menu">
          { children }
        </div>
      </div>
    )
  }
}

Dropdown.defaultProps = {
  icon: "dropdown",
  text: "Select",
  type: "selection",
  on: "click",
  ignoreCase: false,
  allowReselection: false,
  allowAdditions: false,
  hideAdditions: true,
  action: "activate",
  minCharacters: 1,
  match: "both",
  selectOnKeydown: true,
  forceSelection: true,
  allowCategorySelection: false,
  placeholder: "auto",
  direction: 'auto',
  keepOnScreen: true,
  fullTextSearch: true,
  preserveHTML: true,
  sortSelect: false,
  showOnFocus: true,
  allowTab: true,
  duration: 200,
  onChange: null,
  onAdd: null,
  onRemove: null,
  onLabelCreate: null,
  onLabelRemove: null,
  onLabelSelect: null,
  onNoResults: null,
  onShow: null,
  onHide: null
}

Dropdown.Item = ({ children, className, value }) => (
  <div className={ cx("item", className) } data-value={ value }>
    { children }
  </div>
)

export default Dropdown
