import React from 'react'
import cx from 'classnames'
import $ from 'jquery'

import '../scripts/transition'
import '../scripts/dimmer'
import '../scripts/modal'
import './styles'

class Modal extends React.Component {
    constructor(props) {
        super(props)

        this.modal = React.createRef()

        // Bindings
        this.showModal = this.showModal.bind(this)
        this.hideModal = this.hideModal.bind(this)
    }

    componentDidMount() {
        const settings = {
            ...this.props.settings,
            detachable: false
        }

        if (this.props.transition !== undefined) {
            settings.transition = this.props.transition
        }

        if (this.props.onHide !== undefined) {
            settings.onHide = this.props.onHide
        }

        if (this.props.onHidden !== undefined) {
            settings.onHidden = this.props.onHidden
        }

        $(this.modal.current).modal(settings)
    }

    componentWillReceiveProps(nextProps) {
      if (nextProps.show !== this.props.show) {
        if (nextProps.show) {
          this.showModal()
        } else {
          this.hideModal()
        }
      }
    }

    componentWillUnmount() {
        $('.ui.dimmer.modals').remove()
    }

    showModal() {
        $(this.modal.current).modal('show')
    }

    hideModal() {
        $(this.modal.current).modal('hide')
    }

    render() {
        const {
            children,
            className,
            button,
            trigger: Trigger,
            top,
            size
        } = this.props

        const Button = button !== undefined ? () => (
            <div onClick={ this.showModal } className={ cx(
                'ui button',
                button.className, {
                    icon: button.icon !== undefined
                }
            )}>
                <i className={ cx('icon', button.icon) } />
                { button.text }
            </div>
        ) : null

        return (
            <React.Fragment>
                { Button && <Button /> }
                { Trigger && <Trigger onClick={ this.showModal } /> }
                <div className={ cx("ui modal et-module-modal", size, className, {
                    top
                })} ref={ this.modal }>
                    { children }
                </div>
            </React.Fragment>
        )
    }
}

Modal.Header = ({ children, className }) => (
    <div className={ cx("header", className) }>
        { children }
    </div>
)

Modal.Content = ({ children, className }) => (
    <div className={ cx("content", className) }>
        { children }
    </div>
)

Modal.Actions = ({ children, className }) => (
    <div className={ cx("actions", className) }>
        { children }
    </div>
)

Modal.defaultProps = {
  top: false,
  show: false,
  size: ''
}

export default Modal
